<?php

namespace Drupal\azure_search\AzureSearch\Objects;

/**
 * Azure index object.
 */
class AzureIndex {
  private $index;

  const AZURETYPES = [
    "text"    => "Edm.String",
    "string"  => "Edm.String",
    "integer" => "Edm.Int32",
    "double"  => "Edm.Double",
    "decimal" => "Edm.Double",
    "boolean" => "Edm.Boolean",
    "date"    => "Edm.Int64",
    "object"  => "Edm.ComplexType",
    "text_collection"    => "Collection(Edm.String)",
    "string_collection"  => "Collection(Edm.String)",
    "integer_collection" => "Collection(Edm.Int32)",
    "decimal_collection" => "Collection(Edm.Double)",
  ];

  const IS_COLLECTION = [
    "text"    => FALSE,
    "string"  => FALSE,
    "integer" => FALSE,
    "double"  => FALSE,
    "decimal" => FALSE,
    "boolean" => FALSE,
    "date"    => FALSE,
    "object"  => FALSE,
    "text_collection"    => TRUE,
    "string_collection"  => TRUE,
    "integer_collection" => TRUE,
    "decimal_collection" => TRUE,
  ];

  /**
   * Constructs an AzureIndex object.
   */
  public function __construct(String $name) {
    $this->index = new \stdClass();
    $this->index->name = $name;
    $this->index->fields = [];
  }

  /**
   * Add fields to index definition.
   */
  public function addField($name, $type, $key = FALSE) {
    $field = new \stdClass();
    $field->name = $name;
    $field->type = static::AZURETYPES[$type];
    if ($key) {
      $field->key = $key;
    }
    $this->index->fields[] = $field;
  }

  /**
   * Add boosts to index definition.
   */
  public function addScoringProfile($name, $scoring) {

    if (count((array) $scoring)) {
      if (!isset($this->index->scoringProfiles)) {
        $this->index->scoringProfiles = [];
      }

      $scoring_profile = new \stdClass();
      $scoring_profile->name = $name;
      $scoring_profile->text = new \stdClass();
      $scoring_profile->text->weights = $scoring;

      $this->index->scoringProfiles[] = $scoring_profile;
    }
  }

  /**
   * Get azure index definition object.
   *
   * @return mixed
   *   object for index creation
   */
  public function getDefinition() {
    return $this->index;
  }

}
